#ifndef GNUMERIC_PLUGIN_LOTUS_123_LOTUS_FORMULA_H
#define GNUMERIC_PLUGIN_LOTUS_123_LOTUS_FORMULA_H

#include "gnumeric.h"

#define LOTUS_FORMULA_CONSTANT    0x0
#define LOTUS_FORMULA_VARIABLE    0x1
#define LOTUS_FORMULA_RANGE       0x2
#define LOTUS_FORMULA_RETURN      0x3
#define LOTUS_FORMULA_BRACKET     0x4
#define LOTUS_FORMULA_INTEGER     0x5
#define LOTUS_FORMULA_STRING	  0x6

#define LOTUS_FORMULA_LOGICAL_AND 0x14
#define LOTUS_FORMULA_LOGICAL_OR  0x15
#define LOTUS_FORMULA_UNARY_PLUS  0x17


GnmExpr const *lotus_parse_formula (LotusWk1Read *state, guint32 col, guint32 row,
				    guint8 const *data, guint32 len);

#endif
